==> cloudfrontapigatewaylambda-1.48.0-sources.jar: software/amazon/awsconstructs/services/cloudfrontapigatewaylambda/CloudFrontToApiGatewayToLambdaProps.java <==
package software.amazon.awsconstructs.services.cloudfrontapigatewaylambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.8.0 (build 4a047ac)", date = "2020-07-06T19:21:12.608Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cloudfrontapigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-cloudfront-apigateway-lambda.CloudFrontToApiGatewayToLambdaProps")
@software.amazon.jsii.Jsii.Proxy(CloudFrontToApiGatewayToLambdaProps.Jsii$Proxy.class)
public interface CloudFrontToApiGatewayToLambdaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether to create a new Lambda function or use an existing Lambda function.
     * <p>
     * If set to false, you must provide a lambda function object as <code>existingLambdaObj</code>
     * <p>
     * Default: - true
     */
    @org.jetbrains.annotations.NotNull java.lang.Boolean getDeployLambda();

    /**
     * Optional user provided props to override the default props for the API Gateway.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.LambdaRestApiProps getApiGatewayProps() {
        return null;
    }

    /**
     * Optional user provided props to override the default props.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable java.lang.Object getCloudFrontDistributionProps() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object.
     * <p>
     * If <code>deploy</code> is set to false only then this property is required
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
     * <p>
     * Default: - true
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getInsertHttpSecurityHeaders() {
        return null;
    }

    /**
     * Optional user provided props to override the default props for the Lambda function.
     * <p>
     * If <code>deploy</code> is set to true only then this property is required
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudFrontToApiGatewayToLambdaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudFrontToApiGatewayToLambdaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<CloudFrontToApiGatewayToLambdaProps> {
        private java.lang.Boolean deployLambda;
        private software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps;
        private java.lang.Object cloudFrontDistributionProps;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private java.lang.Boolean insertHttpSecurityHeaders;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getDeployLambda}
         * @param deployLambda Whether to create a new Lambda function or use an existing Lambda function. This parameter is required.
         *                     If set to false, you must provide a lambda function object as <code>existingLambdaObj</code>
         * @return {@code this}
         */
        public Builder deployLambda(java.lang.Boolean deployLambda) {
            this.deployLambda = deployLambda;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getApiGatewayProps}
         * @param apiGatewayProps Optional user provided props to override the default props for the API Gateway.
         * @return {@code this}
         */
        public Builder apiGatewayProps(software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps) {
            this.apiGatewayProps = apiGatewayProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getCloudFrontDistributionProps}
         * @param cloudFrontDistributionProps Optional user provided props to override the default props.
         * @return {@code this}
         */
        public Builder cloudFrontDistributionProps(java.lang.Object cloudFrontDistributionProps) {
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object.
         *                          If <code>deploy</code> is set to false only then this property is required
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getInsertHttpSecurityHeaders}
         * @param insertHttpSecurityHeaders Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
         * @return {@code this}
         */
        public Builder insertHttpSecurityHeaders(java.lang.Boolean insertHttpSecurityHeaders) {
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps Optional user provided props to override the default props for the Lambda function.
         *                            If <code>deploy</code> is set to true only then this property is required
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudFrontToApiGatewayToLambdaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public CloudFrontToApiGatewayToLambdaProps build() {
            return new Jsii$Proxy(deployLambda, apiGatewayProps, cloudFrontDistributionProps, existingLambdaObj, insertHttpSecurityHeaders, lambdaFunctionProps);
        }
    }

    /**
     * An implementation for {@link CloudFrontToApiGatewayToLambdaProps}
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudFrontToApiGatewayToLambdaProps {
        private final java.lang.Boolean deployLambda;
        private final software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps;
        private final java.lang.Object cloudFrontDistributionProps;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final java.lang.Boolean insertHttpSecurityHeaders;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.deployLambda = this.jsiiGet("deployLambda", java.lang.Boolean.class);
            this.apiGatewayProps = this.jsiiGet("apiGatewayProps", software.amazon.awscdk.services.apigateway.LambdaRestApiProps.class);
            this.cloudFrontDistributionProps = this.jsiiGet("cloudFrontDistributionProps", java.lang.Object.class);
            this.existingLambdaObj = this.jsiiGet("existingLambdaObj", software.amazon.awscdk.services.lambda.Function.class);
            this.insertHttpSecurityHeaders = this.jsiiGet("insertHttpSecurityHeaders", java.lang.Boolean.class);
            this.lambdaFunctionProps = this.jsiiGet("lambdaFunctionProps", software.amazon.awscdk.services.lambda.FunctionProps.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean deployLambda, final software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps, final java.lang.Object cloudFrontDistributionProps, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final java.lang.Boolean insertHttpSecurityHeaders, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.deployLambda = java.util.Objects.requireNonNull(deployLambda, "deployLambda is required");
            this.apiGatewayProps = apiGatewayProps;
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            this.existingLambdaObj = existingLambdaObj;
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
            this.lambdaFunctionProps = lambdaFunctionProps;
        }

        @Override
        public java.lang.Boolean getDeployLambda() {
            return this.deployLambda;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.LambdaRestApiProps getApiGatewayProps() {
            return this.apiGatewayProps;
        }

        @Override
        public java.lang.Object getCloudFrontDistributionProps() {
            return this.cloudFrontDistributionProps;
        }

        @Override
        public software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public java.lang.Boolean getInsertHttpSecurityHeaders() {
            return this.insertHttpSecurityHeaders;
        }

        @Override
        public software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("deployLambda", om.valueToTree(this.getDeployLambda()));
            if (this.getApiGatewayProps() != null) {
                data.set("apiGatewayProps", om.valueToTree(this.getApiGatewayProps()));
            }
            if (this.getCloudFrontDistributionProps() != null) {
                data.set("cloudFrontDistributionProps", om.valueToTree(this.getCloudFrontDistributionProps()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getInsertHttpSecurityHeaders() != null) {
                data.set("insertHttpSecurityHeaders", om.valueToTree(this.getInsertHttpSecurityHeaders()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-cloudfront-apigateway-lambda.CloudFrontToApiGatewayToLambdaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudFrontToApiGatewayToLambdaProps.Jsii$Proxy that = (CloudFrontToApiGatewayToLambdaProps.Jsii$Proxy) o;

            if (!deployLambda.equals(that.deployLambda)) return false;
            if (this.apiGatewayProps != null ? !this.apiGatewayProps.equals(that.apiGatewayProps) : that.apiGatewayProps != null) return false;
            if (this.cloudFrontDistributionProps != null ? !this.cloudFrontDistributionProps.equals(that.cloudFrontDistributionProps) : that.cloudFrontDistributionProps != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            if (this.insertHttpSecurityHeaders != null ? !this.insertHttpSecurityHeaders.equals(that.insertHttpSecurityHeaders) : that.insertHttpSecurityHeaders != null) return false;
            return this.lambdaFunctionProps != null ? this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps == null;
        }

        @Override
        public int hashCode() {
            int result = this.deployLambda.hashCode();
            result = 31 * result + (this.apiGatewayProps != null ? this.apiGatewayProps.hashCode() : 0);
            result = 31 * result + (this.cloudFrontDistributionProps != null ? this.cloudFrontDistributionProps.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.insertHttpSecurityHeaders != null ? this.insertHttpSecurityHeaders.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            return result;
        }
    }
}

==> cloudfrontapigatewaylambda-1.49.0-sources.jar: software/amazon/awsconstructs/services/cloudfrontapigatewaylambda/CloudFrontToApiGatewayToLambdaProps.java <==
package software.amazon.awsconstructs.services.cloudfrontapigatewaylambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.8.0 (build 4a047ac)", date = "2020-07-09T17:11:25.161Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cloudfrontapigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-cloudfront-apigateway-lambda.CloudFrontToApiGatewayToLambdaProps")
@software.amazon.jsii.Jsii.Proxy(CloudFrontToApiGatewayToLambdaProps.Jsii$Proxy.class)
public interface CloudFrontToApiGatewayToLambdaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Optional user provided props to override the default props for the API Gateway.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.LambdaRestApiProps getApiGatewayProps() {
        return null;
    }

    /**
     * Optional user provided props to override the default props.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable java.lang.Object getCloudFrontDistributionProps() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
     * <p>
     * Default: - true
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getInsertHttpSecurityHeaders() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CloudFrontToApiGatewayToLambdaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudFrontToApiGatewayToLambdaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<CloudFrontToApiGatewayToLambdaProps> {
        private software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps;
        private java.lang.Object cloudFrontDistributionProps;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private java.lang.Boolean insertHttpSecurityHeaders;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getApiGatewayProps}
         * @param apiGatewayProps Optional user provided props to override the default props for the API Gateway.
         * @return {@code this}
         */
        public Builder apiGatewayProps(software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps) {
            this.apiGatewayProps = apiGatewayProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getCloudFrontDistributionProps}
         * @param cloudFrontDistributionProps Optional user provided props to override the default props.
         * @return {@code this}
         */
        public Builder cloudFrontDistributionProps(java.lang.Object cloudFrontDistributionProps) {
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getInsertHttpSecurityHeaders}
         * @param insertHttpSecurityHeaders Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
         * @return {@code this}
         */
        public Builder insertHttpSecurityHeaders(java.lang.Boolean insertHttpSecurityHeaders) {
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
            return this;
        }

        /**
         * Sets the value of {@link CloudFrontToApiGatewayToLambdaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudFrontToApiGatewayToLambdaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public CloudFrontToApiGatewayToLambdaProps build() {
            return new Jsii$Proxy(apiGatewayProps, cloudFrontDistributionProps, existingLambdaObj, insertHttpSecurityHeaders, lambdaFunctionProps);
        }
    }

    /**
     * An implementation for {@link CloudFrontToApiGatewayToLambdaProps}
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudFrontToApiGatewayToLambdaProps {
        private final software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps;
        private final java.lang.Object cloudFrontDistributionProps;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final java.lang.Boolean insertHttpSecurityHeaders;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.apiGatewayProps = this.jsiiGet("apiGatewayProps", software.amazon.awscdk.services.apigateway.LambdaRestApiProps.class);
            this.cloudFrontDistributionProps = this.jsiiGet("cloudFrontDistributionProps", java.lang.Object.class);
            this.existingLambdaObj = this.jsiiGet("existingLambdaObj", software.amazon.awscdk.services.lambda.Function.class);
            this.insertHttpSecurityHeaders = this.jsiiGet("insertHttpSecurityHeaders", java.lang.Boolean.class);
            this.lambdaFunctionProps = this.jsiiGet("lambdaFunctionProps", software.amazon.awscdk.services.lambda.FunctionProps.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.apigateway.LambdaRestApiProps apiGatewayProps, final java.lang.Object cloudFrontDistributionProps, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final java.lang.Boolean insertHttpSecurityHeaders, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.apiGatewayProps = apiGatewayProps;
            this.cloudFrontDistributionProps = cloudFrontDistributionProps;
            this.existingLambdaObj = existingLambdaObj;
            this.insertHttpSecurityHeaders = insertHttpSecurityHeaders;
            this.lambdaFunctionProps = lambdaFunctionProps;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.LambdaRestApiProps getApiGatewayProps() {
            return this.apiGatewayProps;
        }

        @Override
        public java.lang.Object getCloudFrontDistributionProps() {
            return this.cloudFrontDistributionProps;
        }

        @Override
        public software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public java.lang.Boolean getInsertHttpSecurityHeaders() {
            return this.insertHttpSecurityHeaders;
        }

        @Override
        public software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getApiGatewayProps() != null) {
                data.set("apiGatewayProps", om.valueToTree(this.getApiGatewayProps()));
            }
            if (this.getCloudFrontDistributionProps() != null) {
                data.set("cloudFrontDistributionProps", om.valueToTree(this.getCloudFrontDistributionProps()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getInsertHttpSecurityHeaders() != null) {
                data.set("insertHttpSecurityHeaders", om.valueToTree(this.getInsertHttpSecurityHeaders()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-cloudfront-apigateway-lambda.CloudFrontToApiGatewayToLambdaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudFrontToApiGatewayToLambdaProps.Jsii$Proxy that = (CloudFrontToApiGatewayToLambdaProps.Jsii$Proxy) o;

            if (this.apiGatewayProps != null ? !this.apiGatewayProps.equals(that.apiGatewayProps) : that.apiGatewayProps != null) return false;
            if (this.cloudFrontDistributionProps != null ? !this.cloudFrontDistributionProps.equals(that.cloudFrontDistributionProps) : that.cloudFrontDistributionProps != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            if (this.insertHttpSecurityHeaders != null ? !this.insertHttpSecurityHeaders.equals(that.insertHttpSecurityHeaders) : that.insertHttpSecurityHeaders != null) return false;
            return this.lambdaFunctionProps != null ? this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps == null;
        }

        @Override
        public int hashCode() {
            int result = this.apiGatewayProps != null ? this.apiGatewayProps.hashCode() : 0;
            result = 31 * result + (this.cloudFrontDistributionProps != null ? this.cloudFrontDistributionProps.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.insertHttpSecurityHeaders != null ? this.insertHttpSecurityHeaders.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            return result;
        }
    }
}
